"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NeverRetryBackoff = exports.ConstantBackoff = void 0;
/**
 * Backoff that returns a constant interval.
 */
class ConstantBackoff {
    constructor(interval, limit) {
        this.interval = interval;
        this.limit = limit;
    }
    /**
     * @inheritdoc
     */
    next() {
        return instance(this.interval, this.limit);
    }
}
exports.ConstantBackoff = ConstantBackoff;
/**
 * Backoff that never retries.
 */
exports.NeverRetryBackoff = new ConstantBackoff(0, 0);
const instance = (interval, limit, index = 0) => ({
    duration: interval,
    next() {
        if (limit === undefined) {
            return this;
        }
        if (index >= limit - 1) {
            return undefined;
        }
        return instance(interval, limit, index + 1);
    },
});
//# sourceMappingURL=ConstantBackoff.js.map