"use strict";
// Temporary augmentation for TS since @types/node lacks the AbortSignal type,
// and depending on the target milage may vary...
// https://github.com/DefinitelyTyped/DefinitelyTyped/blob/d5323665619bd6034643f11291c1b1405f1f8790/types/node/globals.d.ts#L45-L57
Object.defineProperty(exports, "__esModule", { value: true });
exports.waitForAbort = exports.deriveAbortController = exports.abortedSignal = exports.neverAbortedSignal = void 0;
exports.neverAbortedSignal = new AbortController().signal;
const cancelledSrc = new AbortController();
cancelledSrc.abort();
exports.abortedSignal = cancelledSrc.signal;
/**
 * Creates a new AbortController that is aborted when the parent signal aborts.
 * @private
 */
const deriveAbortController = (signal) => {
    const ctrl = new AbortController();
    if (!signal) {
        return ctrl;
    }
    if (signal.aborted) {
        ctrl.abort();
    }
    const l = () => ctrl.abort();
    signal.addEventListener('abort', l);
    ctrl.signal.addEventListener('abort', () => signal.removeEventListener('abort', l));
    return ctrl;
};
exports.deriveAbortController = deriveAbortController;
const waitForAbort = (signal) => {
    if (signal.aborted) {
        return Promise.resolve();
    }
    return new Promise(resolve => {
        const l = () => {
            resolve();
            signal.removeEventListener('abort', l);
        };
        signal.addEventListener('abort', l);
    });
};
exports.waitForAbort = waitForAbort;
//# sourceMappingURL=abort.js.map